[gparted] Use Gtk::Box for Dialog_Partition_Name (!25)



commit c1f22e28a4244dd758866a6823aa85d40c2f119f
Author: Luca Bacci <luca bacci982 gmail com>
Date:   Wed Feb 27 16:49:19 2019 +0100

    Use Gtk::Box for Dialog_Partition_Name (!25)
    
    Gtk::HBox and Gtk::VBox were deprecated in Gtkmm 3.2.  Replace with
    plain Gtk::Box.
    
    This commit makes the change for Dialog_Partition_Name.cc.
    
    Closes !25 - Modern Gtk3 - part 1

 src/Dialog_Partition_Name.cc | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/Dialog_Partition_Name.cc b/src/Dialog_Partition_Name.cc
index e081583c..3cdfa74b 100644
--- a/src/Dialog_Partition_Name.cc
+++ b/src/Dialog_Partition_Name.cc
@@ -33,8 +33,8 @@ Dialog_Partition_Name::Dialog_Partition_Name( const Partition & partition, int m
        /* TO TRANSLATORS: dialog title, looks like   Set partition name on /dev/hda3 */
        this->set_title( Glib::ustring::compose( _("Set partition name on %1"), partition.get_path() ) );
 
-       // HBox to hole the label and entry box line
-       Gtk::HBox *hbox( manage( new Gtk::HBox() ) );
+       // Horizontal box to hold the label and entry box line
+       Gtk::Box *hbox(manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)));
        hbox->set_border_width( 5 );
        hbox->set_spacing( 10 );
        get_vbox()->pack_start( *hbox, Gtk::PACK_SHRINK );


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]